@@ -4,7 +4,7 @@ from torch import Tensor
 from torch.nn import Module, ModuleList
 
 from ..layer import Linear
-from ..util import generate_inf_seq, ModuleFactory
+from ..util import generate_inf_seq, ModuleFactory, compose
 
 
 class MLP(Module):
@@ -32,6 +32,5 @@ class MLP(Module):
         )
 
     def forward(self, x: Tensor) -> Tensor:
-        for layer in self.layers:
-            x = layer(x)
-        return x
+        f = compose(self.layers)
+        return f(x)
