@@ -1,7 +1,12 @@
+from einops.layers.torch import Rearrange as _Rearrange
+
 from .func import reduce_dict_by, summarize_dict_by, generate_inf_seq, compose, listdir, with_printed, \
     with_printed_shape, is_bad_num, ifelse
 from .type import ModuleFactory, Shape, Device
 from .configuration import Configuration
+from .string_getter import activation_getter, loss_getter
+
+Rearrange = _Rearrange
 
 
 __all__ = [
@@ -17,5 +22,8 @@ __all__ = [
     "ModuleFactory",
     "Shape",
     "Device",
-    "Configuration"
+    "Configuration",
+    "activation_getter",
+    "loss_getter",
+    "Rearrange",
 ]
\ No newline at end of file
